Struct sc_offchain::OffchainWorkerOptions
source · pub struct OffchainWorkerOptions<RA, Block: Block, Storage, CE> {
pub runtime_api_provider: Arc<RA>,
pub keystore: Option<KeystorePtr>,
pub offchain_db: Option<Storage>,
pub transaction_pool: Option<OffchainTransactionPoolFactory<Block>>,
pub network_provider: Arc<dyn NetworkProvider + Send + Sync>,
pub is_validator: bool,
pub enable_http_requests: bool,
pub custom_extensions: CE,
}Expand description
Options for OffchainWorkers
Fields
runtime_api_provider: Arc<RA>Provides access to the runtime api.
keystore: Option<KeystorePtr>Provides access to the keystore.
offchain_db: Option<Storage>Provides access to the offchain database.
Use NoOffchainStorage as type when passing None to have some type that works.
transaction_pool: Option<OffchainTransactionPoolFactory<Block>>Provides access to the transaction pool.
network_provider: Arc<dyn NetworkProvider + Send + Sync>Provides access to network information.
is_validator: boolIs the node running as validator?
enable_http_requests: boolEnable http requests from offchain workers?
If not enabled, any http request will panic.
custom_extensions: CECallback to create custom Extensions that should be registered for the
offchain_worker runtime call.
These Extensions are registered along-side the default extensions and are accessible in
the host functions.
Example:
custom_extensions: |block_hash| {
vec![MyCustomExtension::new()]
}